@@ -22,7 +22,8 @@ use install_wheel_rs::metadata::read_archive_metadata;
 use platform_tags::Tags;
 use pypi_types::{HashDigest, Metadata12, Metadata23, RequiresTxt};
 use uv_cache::{
-    ArchiveTimestamp, CacheBucket, CacheEntry, CacheShard, CachedByTimestamp, Timestamp, WheelCache,
+    ArchiveTimestamp, Cache, CacheBucket, CacheEntry, CacheShard, CachedByTimestamp, Removal,
+    Timestamp, WheelCache,
 };
 use uv_client::{
     CacheControl, CachedClientError, Connectivity, DataWithCachePolicy, RegistryClient,
@@ -1610,6 +1611,76 @@ impl<'a, T: BuildContext> SourceDistributionBuilder<'a, T> {
     }
 }
 
+/// Prune any unused source distributions from the cache.
+pub fn prune(cache: &Cache) -> Result<Removal, Error> {
+    let mut removal = Removal::default();
+
+    let bucket = cache.bucket(CacheBucket::SourceDistributions);
+    if bucket.is_dir() {
+        for entry in walkdir::WalkDir::new(bucket) {
+            let entry = entry.map_err(Error::CacheWalk)?;
+
+            if !entry.file_type().is_dir() {
+                continue;
+            }
+
+            // If we find a `revision.http` file, read the pointer, and remove any extraneous
+            // directories.
+            let revision = entry.path().join("revision.http");
+            if revision.is_file() {
+                let pointer = HttpRevisionPointer::read_from(revision)?;
+                if let Some(pointer) = pointer {
+                    // Remove all sibling directories that are not referenced by the pointer.
+                    for sibling in entry.path().read_dir().map_err(Error::CacheRead)? {
+                        let sibling = sibling.map_err(Error::CacheRead)?;
+                        if sibling.file_type().map_err(Error::CacheRead)?.is_dir() {
+                            let sibling_name = sibling.file_name();
+                            if sibling_name != pointer.revision.id().as_str() {
+                                debug!(
+                                    "Removing dangling source revision: {}",
+                                    sibling.path().display()
+                                );
+                                removal +=
+                                    uv_cache::rm_rf(sibling.path()).map_err(Error::CacheWrite)?;
+                            }
+                        }
+                    }
+                }
+
+                continue;
+            }
+
+            // If we find a `revision.rev` file, read the pointer, and remove any extraneous
+            // directories.
+            let revision = entry.path().join("revision.rev");
+            if revision.is_file() {
+                let pointer = LocalRevisionPointer::read_from(revision)?;
+                if let Some(pointer) = pointer {
+                    // Remove all sibling directories that are not referenced by the pointer.
+                    for sibling in entry.path().read_dir().map_err(Error::CacheRead)? {
+                        let sibling = sibling.map_err(Error::CacheRead)?;
+                        if sibling.file_type().map_err(Error::CacheRead)?.is_dir() {
+                            let sibling_name = sibling.file_name();
+                            if sibling_name != pointer.revision.id().as_str() {
+                                debug!(
+                                    "Removing dangling source revision: {}",
+                                    sibling.path().display()
+                                );
+                                removal +=
+                                    uv_cache::rm_rf(sibling.path()).map_err(Error::CacheWrite)?;
+                            }
+                        }
+                    }
+                }
+
+                continue;
+            }
+        }
+    }
+
+    Ok(removal)
+}
+
 /// Validate that the source distribution matches the built metadata.
 fn validate(source: &BuildableSource<'_>, metadata: &Metadata23) -> Result<(), Error> {
     if let Some(name) = source.name() {
