@@ -73,7 +73,7 @@ impl GitSource {
             // If we have a locked revision, and we have a preexisting database
             // which has that revision, then no update needs to happen.
             (Some(rev), Some(db)) if db.contains(rev.into()) => {
-                debug!("Using existing git source `{:?}`", self.git.repository);
+                debug!("Using existing Git source `{}`", self.git.repository);
                 (db, rev, None)
             }
 
@@ -82,7 +82,7 @@ impl GitSource {
             // situation that we have a locked revision but the database
             // doesn't have it.
             (locked_rev, db) => {
-                debug!("Updating git source `{:?}`", self.git.repository);
+                debug!("Updating Git source `{}`", self.git.repository);
 
                 // Report the checkout operation to the reporter.
                 let task = self.reporter.as_ref().map(|reporter| {
