@@ -529,7 +529,9 @@ impl ManagedPythonDownload {
     }
 
     pub fn python_version(&self) -> PythonVersion {
-        self.key.version()
+        self.key
+            .version()
+            .expect("Managed Python downloads should always have valid versions")
     }
 
     /// Return the [`Url`] to use when downloading the distribution. If a mirror is set via the
